from setuptools import setup

setup(
    name="clang",
    author="Ethan Smith",
    author_email="ethan@ethanhs.me",
    version="6.0.0",
    url="https://github.com/ethanhs/clang",
    packages=["clang"],
)
